==================================================
:mod:`numina.types` --- Data types
==================================================

.. automodule:: numina.types
   :synopsis: TBD
   :members:


.. automodule:: numina.types.base
   :synopsis: TBD
   :members:


.. automodule:: numina.types.array
   :synopsis: TBD
   :members:

.. automodule:: numina.types.dataframe
   :synopsis: TBD
   :members:

.. automodule:: numina.types.datatype
   :synopsis: TBD
   :members:

.. automodule:: numina.types.frame
   :synopsis: TBD
   :members:

.. automodule:: numina.types.linescatalog
   :synopsis: TBD
   :members:


.. automodule:: numina.types.multitype
   :synopsis: TBD
   :members:

.. automodule:: numina.types.qc
   :synopsis: Quality Control for Numina
   :members:

QA Levels
---------

The numeric values of the QC levels are given in this table.

+--------------+---------------+
| Level        | Numeric value |
+==============+===============+
| ``GOOD``     | 100           |
+--------------+---------------+
| ``FAIR``     | 90            |
+--------------+---------------+
| ``BAD``      | 70            |
+--------------+---------------+


.. automodule:: numina.types.structured
   :synopsis: TBD
   :members: